@@ -1,27 +1,11 @@
-# coding=utf-8
-
-from __future__ import unicode_literals
-from __future__ import print_function
-
-import os
-import sys
 import argparse
-
-import random
-
-from faker import Faker, documentor
-from faker import VERSION
-from faker.config import AVAILABLE_LOCALES, DEFAULT_LOCALE, META_PROVIDERS_MODULES
-
 import logging
+import os
+import random
+import sys
 
-if sys.version < '3':
-    text_type = unicode
-    binary_type = str
-else:
-    text_type = str
-    binary_type = bytes
-
+from faker import VERSION, Faker, documentor
+from faker.config import AVAILABLE_LOCALES, DEFAULT_LOCALE, META_PROVIDERS_MODULES
 
 __author__ = 'joke2k'
 
@@ -32,7 +16,7 @@ def print_provider(doc, provider, formatters, excludes=None, output=None):
         excludes = []
 
     print(file=output)
-    print("### {0}".format(
+    print("### {}".format(
           doc.get_provider_name(provider)), file=output)
     print(file=output)
 
@@ -40,14 +24,14 @@ def print_provider(doc, provider, formatters, excludes=None, output=None):
         if signature in excludes:
             continue
         try:
-            lines = text_type(example).expandtabs().splitlines()
+            lines = str(example).expandtabs().splitlines()
         except UnicodeDecodeError:
             # The example is actually made of bytes.
             # We could coerce to bytes, but that would fail anyway when we wiil
             # try to `print` the line.
             lines = ["<bytes>"]
         except UnicodeEncodeError:
-            raise Exception('error on "{0}" with value "{1}"'.format(
+            raise Exception('error on "{}" with value "{}"'.format(
                             signature, example))
         margin = max(30, doc.max_name_len + 1)
         remains = 150 - margin
@@ -58,7 +42,7 @@ def print_provider(doc, provider, formatters, excludes=None, output=None):
                     fake=signature,
                     separator=separator,
                     example=line[i * remains:(i + 1) * remains],
-                    margin=margin
+                    margin=margin,
                 ), file=output)
                 signature = separator = ' '
 
@@ -72,7 +56,7 @@ def print_doc(provider_or_field=None,
     fake.seed_instance(seed)
 
     from faker.providers import BaseProvider
-    base_provider_formatters = [f for f in dir(BaseProvider)]
+    base_provider_formatters = list(dir(BaseProvider))
 
     if provider_or_field:
         if '.' in provider_or_field:
@@ -97,7 +81,7 @@ def print_doc(provider_or_field=None,
                     end='',
                     file=output)
             except AttributeError:
-                raise ValueError('No faker found for "{0}({1})"'.format(
+                raise ValueError('No faker found for "{}({})"'.format(
                     provider_or_field, args))
 
     else:
@@ -113,7 +97,7 @@ def print_doc(provider_or_field=None,
             if language == lang:
                 continue
             print(file=output)
-            print('## LANGUAGE {0}'.format(language), file=output)
+            print('## LANGUAGE {}'.format(language), file=output)
             fake = Faker(locale=language)
             fake.seed_instance(seed)
             d = documentor.Documentor(fake)
@@ -124,7 +108,7 @@ def print_doc(provider_or_field=None,
                 print_provider(d, p, fs, output=output)
 
 
-class Command(object):
+class Command:
 
     def __init__(self, argv=None):
         self.argv = argv or sys.argv[:]
@@ -179,12 +163,12 @@ examples:
         formatter_class = argparse.RawDescriptionHelpFormatter
         parser = argparse.ArgumentParser(
             prog=self.prog_name,
-            description='{0} version {1}'.format(self.prog_name, VERSION),
+            description='{} version {}'.format(self.prog_name, VERSION),
             epilog=epilog,
             formatter_class=formatter_class)
 
         parser.add_argument("--version", action="version",
-                            version="%(prog)s {0}".format(VERSION))
+                            version="%(prog)s {}".format(VERSION))
 
         parser.add_argument('-v',
                             '--verbose',
@@ -252,7 +236,7 @@ examples:
             logging.basicConfig(level=logging.CRITICAL)
 
         random.seed(arguments.seed)
-        seeds = random.sample(range(arguments.repeat*10),arguments.repeat)
+        seeds = random.sample(range(arguments.repeat*10), arguments.repeat)
 
         for i in range(arguments.repeat):
 
@@ -261,7 +245,7 @@ examples:
                       lang=arguments.lang,
                       output=arguments.o,
                       seed=seeds[i],
-                      includes=arguments.include
+                      includes=arguments.include,
                       )
             print(arguments.sep, file=arguments.o)
 
