@@ -1,5 +1,6 @@
 from .. import Provider as BankProvider
 
+
 class Provider(BankProvider):
-    bban_format = '########################'
+    bban_format = '#######################'
     country_code = 'FR'
